# PyStrukts

[![Build](https://github.com/rubenperezm/pystrukts/actions/workflows/test.yml/badge.svg)](https://github.com/rubenperezm/pystrukts/actions/workflows/test.yml/badge.svg)
[![codecov](https://codecov.io/gh/rubenperezm/pystrukts/graph/badge.svg?token=OLV3EOPYFI)](https://codecov.io/gh/rubenperezm/pystrukts)
[![PyPI Version](https://img.shields.io/pypi/v/pystrukts.svg)](https://pypi.org/project/pystrukts)
[![Python Versions](https://img.shields.io/pypi/pyversions/pystrukts.svg)](https://pypi.org/project/pystrukts)


A Python library for data structures. This library provides more than 10 advanced data structures not available in the Python standard library.

## Installation

```bash
pip install pystrukts
```

## Data Structures
### Lists
- [x] Singly Linked Node
- [x] Singly Linked List
- [x] Doubly Linked Node
- [x] Doubly Linked List
- [x] Circular Linked List (Single, Double)

### Trees
- [x] Binary Tree
- [x] Generic Tree
- [x] Binary Search Tree
- [x] Fenwick Trees (RUPQ, RURQ)
- [x] Trie

### Graphs
- [x] Adjacency Matrix
- [x] Adjacency List

### Others
- [x] Disjoint Set (Union Find)
- [x] Max Heap
